Class: GroupDocsComparisonCloud::CompareApi

Inherits:
Object
  • Object
show all
Defined in:
lib/groupdocs_comparison_cloud/api/compare_api.rb

Overview

GroupDocs.Comparison Cloud API

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config) ⇒ CompareApi

Initializes new instance of CompareApi

Parameters:



43
44
45
46
47
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 43

def initialize(config)
  @config = config
  @api_client = ApiClient.new(config)
  @access_token = nil
end

Instance Attribute Details

#configObject

Returns the value of attribute config.



34
35
36
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 34

def config
  @config
end

Class Method Details

.from_config(config) ⇒ CompareApi

Initializes new instance of CompareApi

Parameters:

Returns:



63
64
65
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 63

def self.from_config(config)
  return new(config)
end

.from_keys(app_sid, app_key) ⇒ CompareApi

Initializes new instance of CompareApi

Parameters:

  • Application (app_sid)

    identifier (App SID)

  • Application (app_key)

    private key (App Key)

Returns:



54
55
56
57
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 54

def self.from_keys(app_sid, app_key)
  config = Configuration.new(app_sid, app_key)
  return new(config)
end

Instance Method Details

#comparisons(request) ⇒ Link

Compares source and target documents and returns a link to saved result

Parameters:

  • request

    comparisons_request

Returns:



71
72
73
74
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 71

def comparisons(request)
  data, _status_code, _headers = comparisons_with_http_info(request)
  data
end

#comparisons_with_http_info(request) ⇒ Array<(Link, Fixnum, Hash)>

Compares source and target documents and returns a link to saved result

Link data, response status code and response headers

Parameters:

  • request

    comparisons_request

Returns:

  • (Array<(Link, Fixnum, Hash)>)

Raises:

  • (ArgumentError)


81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 81

def comparisons_with_http_info(request)
  raise ArgumentError, 'Incorrect request type' unless request.is_a? ComparisonsRequest

  @api_client.config.logger.debug 'Calling API: CompareApi.comparisons ...' if @api_client.config.debugging
  # verify the required parameter 'comparison_options' is set
  raise ArgumentError, 'Missing the required parameter comparison_options when calling CompareApi.comparisons' if @api_client.config.client_side_validation && request.comparison_options.nil?
  # resource path
  local_var_path = '/comparison/comparisons'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(request.comparison_options)
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
                                                    header_params: header_params,
                                                    query_params: query_params,
                                                    form_params: form_params,
                                                    body: post_body,
                                                    access_token: get_access_token,
                                                    return_type: 'Link')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called:
    CompareApi#comparisons\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  [data, status_code, headers]
end

#post_changes(request) ⇒ Array<ChangeInfo>

Retrieves a list of changes between source and target documents

Parameters:

  • request

    post_changes_request

Returns:



123
124
125
126
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 123

def post_changes(request)
  data, _status_code, _headers = post_changes_with_http_info(request)
  data
end

#post_changes_with_http_info(request) ⇒ Array<(Array<ChangeInfo>, Fixnum, Hash)>

Retrieves a list of changes between source and target documents

Array<ChangeInfo> data, response status code and response headers

Parameters:

  • request

    post_changes_request

Returns:

Raises:

  • (ArgumentError)


133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 133

def post_changes_with_http_info(request)
  raise ArgumentError, 'Incorrect request type' unless request.is_a? PostChangesRequest

  @api_client.config.logger.debug 'Calling API: CompareApi.post_changes ...' if @api_client.config.debugging
  # verify the required parameter 'comparison_options' is set
  raise ArgumentError, 'Missing the required parameter comparison_options when calling CompareApi.post_changes' if @api_client.config.client_side_validation && request.comparison_options.nil?
  # resource path
  local_var_path = '/comparison/changes'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(request.comparison_options)
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
                                                    header_params: header_params,
                                                    query_params: query_params,
                                                    form_params: form_params,
                                                    body: post_body,
                                                    access_token: get_access_token,
                                                    return_type: 'Array<ChangeInfo>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called:
    CompareApi#post_changes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  [data, status_code, headers]
end

#put_changes(request) ⇒ Array<ChangeInfo>

Retrieves a list of changes between source and target documents supplied directly as multipart/form-data

Parameters:

  • request

    put_changes_request

Returns:



175
176
177
178
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 175

def put_changes(request)
  data, _status_code, _headers = put_changes_with_http_info(request)
  data
end

#put_changes_document(request) ⇒ Link

Accepts or rejects changes to the resultant document and returns a link to saved result

Parameters:

  • request

    put_changes_document_request

Returns:



233
234
235
236
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 233

def put_changes_document(request)
  data, _status_code, _headers = put_changes_document_with_http_info(request)
  data
end

#put_changes_document_with_http_info(request) ⇒ Array<(Link, Fixnum, Hash)>

Accepts or rejects changes to the resultant document and returns a link to saved result

Link data, response status code and response headers

Parameters:

  • request

    put_changes_document_request

Returns:

  • (Array<(Link, Fixnum, Hash)>)

Raises:

  • (ArgumentError)


243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 243

def put_changes_document_with_http_info(request)
  raise ArgumentError, 'Incorrect request type' unless request.is_a? PutChangesDocumentRequest

  @api_client.config.logger.debug 'Calling API: CompareApi.put_changes_document ...' if @api_client.config.debugging
  # verify the required parameter 'updates_options' is set
  raise ArgumentError, 'Missing the required parameter updates_options when calling CompareApi.put_changes_document' if @api_client.config.client_side_validation && request.updates_options.nil?
  # resource path
  local_var_path = '/comparison/updates'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(request.updates_options)
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
                                                    header_params: header_params,
                                                    query_params: query_params,
                                                    form_params: form_params,
                                                    body: post_body,
                                                    access_token: get_access_token,
                                                    return_type: 'Link')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called:
    CompareApi#put_changes_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  [data, status_code, headers]
end

#put_changes_with_http_info(request) ⇒ Array<(Array<ChangeInfo>, Fixnum, Hash)>

Retrieves a list of changes between source and target documents supplied directly as multipart/form-data

Array<ChangeInfo> data, response status code and response headers

Parameters:

  • request

    put_changes_request

Returns:

Raises:

  • (ArgumentError)


185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/groupdocs_comparison_cloud/api/compare_api.rb', line 185

def put_changes_with_http_info(request)
  raise ArgumentError, 'Incorrect request type' unless request.is_a? PutChangesRequest

  @api_client.config.logger.debug 'Calling API: CompareApi.put_changes ...' if @api_client.config.debugging
  # verify the required parameter 'source_file' is set
  raise ArgumentError, 'Missing the required parameter source_file when calling CompareApi.put_changes' if @api_client.config.client_side_validation && request.source_file.nil?
  # verify the required parameter 'target_files' is set
  raise ArgumentError, 'Missing the required parameter target_files when calling CompareApi.put_changes' if @api_client.config.client_side_validation && request.target_files.nil?
  # resource path
  local_var_path = '/comparison/changes'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params[downcase_first_letter('sourceFile')] = request.source_file
  form_params[downcase_first_letter('targetFiles')] = request.target_files
  form_params[downcase_first_letter('settings')] = request.settings unless request.settings.nil?
  form_params[downcase_first_letter('changeType')] = request.change_type unless request.change_type.nil?

  # http body (model)
  post_body = nil
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
                                                    header_params: header_params,
                                                    query_params: query_params,
                                                    form_params: form_params,
                                                    body: post_body,
                                                    access_token: get_access_token,
                                                    return_type: 'Array<ChangeInfo>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called:
    CompareApi#put_changes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  [data, status_code, headers]
end